#
# spec file for package dhall-yaml
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name dhall-yaml
%bcond_with tests
Name:           %{pkg_name}
Version:        1.2.9
Release:        bp155.2.16
Summary:        Convert between Dhall and YAML
License:        GPL-3.0-or-later
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{name}-%{version}/revision/2.cabal#/%{name}.cabal
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-HsYAML-aeson-devel
BuildRequires:  ghc-HsYAML-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-dhall-devel
BuildRequires:  ghc-dhall-json-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-prettyprinter-ansi-terminal-devel
BuildRequires:  ghc-prettyprinter-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-vector-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-expected-failure-devel
BuildRequires:  ghc-tasty-hunit-devel
%endif

%description
Use this package if you want to convert between Dhall expressions and YAML.
You can use this package as a library or an executable:

* See the "Dhall.Yaml" module if you want to use this package as a library

* Use the 'dhall-to-yaml-ng' program from this package if you want an
executable.

%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%autosetup
cp -p %{SOURCE1} %{name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/dhall-to-yaml-ng
%{_bindir}/yaml-to-dhall

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Thu Feb  3 2022 Peter Simons <psimons@suse.com>
- Update dhall-yaml to version 1.2.9 revision 2.
  1.2.9
  * [Build against `aeson-2.0`](https://github.com/dhall-lang/dhall-haskell/pull/2315)
* Sun Nov  7 2021 psimons@suse.com
- Update dhall-yaml to version 1.2.8 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Aug 22 2021 psimons@suse.com
- Update dhall-yaml to version 1.2.8.
  1.2.8
  * Build against `dhall-1.40.0`
* Fri Jun  4 2021 psimons@suse.com
- Update dhall-yaml to version 1.2.7.
  1.2.7
  * Build against `dhall-1.39.0`
* Mon Mar 29 2021 psimons@suse.com
- Update dhall-yaml to version 1.2.6.
  1.2.6
  * [Allow bytestring-0.11](https://github.com/dhall-lang/dhall-haskell/pull/2144)
* Sat Feb 13 2021 psimons@suse.com
- Update dhall-yaml to version 1.2.5 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Jan 28 2021 psimons@suse.com
- Update dhall-yaml to version 1.2.5.
  1.2.5
  * Build against `dhall-1.38.0`, `tasty-1.4`, and `tasty-silver-3.2`
* Tue Dec 29 2020 psimons@suse.com
- Update dhall-yaml to version 1.2.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Dec  7 2020 psimons@suse.com
- Update dhall-yaml to version 1.2.4.
  1.2.4
  * Build against `dhall-1.37.0`
* Thu Oct 22 2020 psimons@suse.com
- Update dhall-yaml to version 1.2.3.
  1.2.3
  * [Fix command-line completions for files](https://github.com/dhall-lang/dhall-haskell/pull/2034)
* Sat Sep 12 2020 psimons@suse.com
- Update dhall-yaml to version 1.2.2.
  1.2.2
  * [The `--documents` flag now wraps non-`List`s in a document](https://github.com/dhall-lang/dhall-haskell/pull/1977)
* Tue Sep  8 2020 psimons@suse.com
- Add dhall-yaml at version 1.2.1 revision 2.
